==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/subversion/svncopyjob_p.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef KDEVPLATFORM_PLUGIN_SVNCOPYJOB_P_H
#define KDEVPLATFORM_PLUGIN_SVNCOPYJOB_P_H

#include "svninternaljobbase.h"

class SvnInternalCopyJob : public SvnInternalJobBase
{
    Q_OBJECT
public:
    SvnInternalCopyJob( SvnJobBase* parent = 0 );
    void setSourceLocation( const KUrl& );
    void setDestinationLocation( const KUrl& );

    KUrl sourceLocation() const;
    KUrl destinationLocation() const;
protected:
    void run();
private:
    KUrl m_sourceLocation;
    KUrl m_destinationLocation;
};


#endif

==> kdevplatform-4.90.90.tar.xz: kdevplatform-4.90.90/plugins/subversion/svncopyjob_p.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef KDEVPLATFORM_PLUGIN_SVNCOPYJOB_P_H
#define KDEVPLATFORM_PLUGIN_SVNCOPYJOB_P_H

#include "svninternaljobbase.h"

class SvnInternalCopyJob : public SvnInternalJobBase
{
    Q_OBJECT
public:
    explicit SvnInternalCopyJob( SvnJobBase* parent = 0 );
    void setSourceLocation( const QUrl& );
    void setDestinationLocation( const QUrl& );

    QUrl sourceLocation() const;
    QUrl destinationLocation() const;
protected:
    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread* thread) override;
private:
    QUrl m_sourceLocation;
    QUrl m_destinationLocation;
};


#endif
